/*
                             View Drawing
 */

#ifndef VIEWDRAW_H
#define VIEWDRAW_H

#include <gtk/gtk.h>
#include "view.h"

#ifndef gbool
# define gbool	gboolean
#endif


extern void View2DDraw(
	vma_view2d_struct *v, vma_view_palette_struct *palette,
	gint vp_width, gint vp_height,
	gbool swap_buffers
);
extern void View3DDraw(
	vma_view3d_struct *v, vma_view_palette_struct *palette,
        gint vp_width, gint vp_height,
        gbool swap_buffers
);

#endif	/* VIEWDRAW_H */
